function y=tremplin(psi0,zl,Kfrein);

% Il faut choisir psi0 dans la plage adquate, calcule avec plageav

% zl est l'altitude de survol de la lune en km

% Kfrein est un coefficient de freinage en sortie de sphre d'influence
% lunaire, 0 < Kfrein < 1   ---->  DV=(1-Kfrein)*Vinfinie/lune

% -----------------------------------------------------------------------------
% -----------------  RECHERCHE DE LA PLAGE DES POSITIONS LUNE -----------------
% DONNANT UNE SORTIE ELLIPTIQUE ET UN PERIGEE PROCHE DE LA TERRE (< 20000 km)
% -----------------------------------------------------------------------------

    data;  % Initialisation
    load vp;
    z=orbitc1(vp);         %FONCTION donnant les caractristiques de l'orbite c1

    a=z(1);e=z(2);p=z(3);T=z(4);apog=z(5);
       
%  La rencontre ne peut avoir lieu qu'entre ces deux limites
% ---- Limites basse et haute en rayon vecteur ------
  

  Rmin=317000;  %  384000-660000-1000  contact arrire impossible
  Rmax=min(451000,apog);  %  451000=384000+66000+1000   contact avant impossible
  
  possibl=0;  % Initialisation de la valeur qui sera 0 ou 1 

 % ---------   Coordonnes capsule    --------

   r=Rmin;i=0;  % Initialisation de la boucle while
 
while ((r-Rmin+1)*(Rmax+1-r)>0)&(possibl<1),  % Balayage tant que la sonde est en dehors
   
    % ------------- Position  capsule -----
    teta=acos((p/r-1)/e);
    xs=r.*cos(teta-pi/2);
    ys=r.*sin(teta-pi/2);

    % --------- Calcul du temps  -----------

    fi=acos((e+cos(teta))./(1+e.*cos(teta)));
    temps=(a^3/mut)^0.5*(fi-e*sin(fi));
       
    % ---------  Coordonnes Lune ----------   
    psi=psi0+wl*temps;
      
    xl=D*cos(psi-pi/2);
    yl=D*sin(psi-pi/2);  
  
    % ------  Distance Sonde-Lune -------
    
    dist=((abs(xs-xl)).^2+(abs(ys-yl)).^2).^0.5;   
    if dist<=66000,                                % La sonde vient juste de rentrer
         possibl=1;

    % ------  Vitesse relative, vitesse capsule et Lune ---------------
   
         coeff=(mut*a/r/r)^0.5;
         vs(1)=-coeff*sin(fi);
         vs(2)=coeff*(1-e*e)^0.5*cos(fi);

         VL=(mut/D)^0.5;
         vl(1)=-VL*sin(psi-pi/2);
         vl(2)=VL*cos(psi-pi/2);
    
         vinf1=vs-vl;
         rayon(1)=xs-xl;
         rayon(2)=ys-yl;

   
         test=(rayon(1)*vinf1(2)-rayon(2)*vinf1(1))&(vinf1*rayon'<0);  % Test de survol avant
         if test>0,
            survol_avant=1;
         end 
         
         break;
    end  
   
   i=i+1;r=Rmin+i*1000;
 
end  % Fin de boucle while

% -------------------------------------------------------------------------------------
% ---                      CALCUL DE VITESSE INFINIE 2 
% -------------------------------------------------------------------------------------
    rph=RL+zl;     
    Norm_vinf=norm(vinf1); ah=mul/Norm_vinf^2;  % V infinie et ah hyperbole
    eh=rph/ah+1;
    XL=-vinf1/Norm_vinf;  %   unitaire de asymptote arrive (vers l'infini)
    YL=[-XL(2) XL(1)];    % Unitaire normal Z^XL

    % Calcul de phi demi angle asymptote connaissant Vinfinie et rp
    
    phi=acos(1/eh);

    % Calcul de vitesse infinie 2

    vinf2=Norm_vinf*(cos(2*phi)*XL+sin(2*phi)*YL);
  
    % Temps de vol hyperbolique

    phivol=acosh((1+rspher/ah)/eh);
    tempsvol=(ah^3/mul)^0.5*(eh*sinh(phivol)-phivol);
    
    % Heure de sortie et conditions de sortie
    
    t2=temps+2*tempsvol;

    % Position-vitesse Lune

    psi2=psi0+wl*t2;
      
    xl2=D*cos(psi-pi/2);
    yl2=D*sin(psi-pi/2);  

    vl2(1)=-VL*sin(psi-pi/2);
    vl2(2)=VL*cos(psi-pi/2);
    
% -------------------------------------------------------------------------------------
% ---                    CALCUL DE POSITION-VITESSE GEOCENTRIQUE 2 
%                   ET DU TEMPS COMPLET DE RETOUR JUSQU'AU POINT D'ENTREE
% -------------------------------------------------------------------------------------

    % Position de sortie  l'infini de l'asymptote 2, au temps t2 de sortie

    R(1)=xl2+rspher*vinf2(1)/Norm_vinf;
    R(2)=yl2+rspher*vinf2(2)/Norm_vinf;
    r2=norm(R);
    % Vitesse de sortie gocentrique

    V=vinf2+vl2;
    
    % FREINAGE EN SORTIE DE SPHERE D'INLUENCE

    deltaV=norm((1-Kfrein)*V);
    if Kfrein<1,
           V=Kfrein*V;
    end
    % Energie sur le retour

    E2=0.5*norm(V)^2-mut/norm(R);

    % Calcul de la constante des aires K

    K=R(1)*V(2)-R(2)*V(1);

    % Excentricit

    e2=(1+2*E2*K*K/mut^2)^0.5;

     if E2<0,
       a2=-mut/2/E2;
       % Rayon vecteur prige
       Rp2=a2*(1-e2);
       % CALCUL DU TEMPS DEPUIS SORTIE SPHERE JUSQU'A TERRE
       fit=acos((1-r2/a2)/e2);
       TempsRetour=(a2^3/mut)^0.5*(fit-e2*sin(fit));
    else
       a2=mut/2/E2;
      % Rayon vecteur prige
       Rp2=a2*(e2-1);
       % CALCUL DU TEMPS DEPUIS SORTIE SPHERE JUSQU'A TERRE
       fit=acosh((1+r2/a2)/e2);
       TempsRetour=(a2^3/mut)^0.5*(-fit+e2*sinh(fit));
    end   


% ---------------  CALCUL DU TEMPS TOTAL DEPUIS LE DEPART    -------------

   t3=t2+TempsRetour;

 % --------------------------------  SORTIES ------------------------------

   y(1)=Rp2;                % Rayon vecteur prige en km
   y(2)=t3/86400;           % TEMPS DE VOL TOTAL en jours
   y(3)=psi0;               % Position Lune en radians
   y(4)=vp;                 % Vitesse de tir initiale, en km/s
   y(5)=zl;                 % Altitude de survol Lune, en km
   y(6)=deltaV;             % Freinage en km/s
   y(7)=temps/86400;              % temps de vol aller
   y(8)=2*tempsvol/86400;         % Temps de survol Lune
   y(9)=TempsRetour/86400;        % Temps retour
 end
   